==> haskell-parsers-0.12.11-125-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsers
version:              0.12.11
visibility:           public
id:                   parsers-0.12.11-GQJpRLe968oESf6mSDWSbn
key:                  parsers-0.12.11-GQJpRLe968oESf6mSDWSbn
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  8c2571f53443a4ca2f8dcabaeaeb5994
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.2.8/site-local/parsers-0.12.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/parsers-0.12.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.11-GQJpRLe968oESf6mSDWSbn
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW binary-0.8.9.0
    charset-0.3.10-LezP165rmys966acYF7Rgn containers-0.6.5.1 mtl-2.2.2
    parsec-3.1.15.0 scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.12-34.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-J6Kx5NEOkx96ahWlotaW3x
key:                  parsers-0.12.12-J6Kx5NEOkx96ahWlotaW3x
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  0c9a8be5b5366e3ced880cbb7b9ef702
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-J6Kx5NEOkx96ahWlotaW3x
depends:
    attoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo base-4.17.2.1
    binary-0.8.9.1 charset-0.3.12-As0Se6l0gXg2ITq6XTycKh
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
